.. k8s documentation master file, created by
   sphinx-quickstart on Thu Aug  3 16:03:43 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to k8s's documentation!
===============================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   tutorial
   developer
   modules/modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
